@@ -3,7 +3,10 @@ from docx.shared import Inches
 from eda_report.univariate import Variable
 from eda_report.multivariate import MultiVariable
 from eda_report.validate import validate_input_dtype
+from tqdm import tqdm
 import logging
+
+
 logging.basicConfig(
     format='[%(levelname)s %(asctime)s.%(msecs)03d] %(message)s',
     level=logging.INFO, datefmt='%H:%M:%S'
@@ -11,23 +14,43 @@ logging.basicConfig(
 
 
 class ReportDocument:
+    """The class with methods to create and populate the .docx report.
+    """
     def __init__(self, data, title='Exploratory Data Analysis Report',
-                 output_filename='basic-eda-report.docx',
-                 graph_colour='orangered', table_style='Table Grid'):
+                 output_filename='eda-report.docx',
+                 graph_color='orangered', table_style='Table Grid'):
+        """Initialise an instance of :class:`ReportDocument`.
+
+        :param data: The data to analyse.
+        :type data: Array-like, sequence, iterable
+        :param title: The top level heading for the report, defaults to
+            'Exploratory Data Analysis Report'.
+        :type title: str, optional
+        :param output_filename: The name to give the generated report file,
+            defaults to 'eda-report.docx'.
+        :type output_filename: str, optional
+        :param graph_color: A valid matplotlib color specifier, defaults
+            to 'orangered'.
+        :type graph_color: str, optional
+        :param table_style: *Microsoft Word* table style to apply to the
+            created tables, defaults to 'Table Grid'.
+        :type table_style: str, optional
+        """
         self.data = validate_input_dtype(data)
         self.TITLE = title
-        self.GRAPH_COLOUR = graph_colour
+        self.GRAPH_COLOR = graph_color
         self.TABLE_STYLE = table_style
         self.OUTPUT_FILENAME = output_filename
         self.document = Document()
         self.get_report()
 
     def get_report(self):
-        """Calculate statistics, plot graphs, and save results as a .docx file.
+        """Calculate summary statistics, plot graphs, and save the results as
+        a .docx file.
         """
         logging.info('Assessing correlation in numeric variables...')
         self.variables = MultiVariable(self.data,
-                                       graph_colour=self.GRAPH_COLOUR)
+                                       graph_color=self.GRAPH_COLOR)
         logging.info('Done. Summarising each variable...')
         self._create_title_page()  # begin the report document
         self._get_variable_info()  # summarise each variable
@@ -39,7 +62,8 @@ class ReportDocument:
         logging.info(f'Done. Results saved as {self.OUTPUT_FILENAME!r}')
 
     def _create_title_page(self):
-        """Add a title and a brief summary of the data."""
+        """Add a title and a brief summary of the data.
+        """
         # Title
         self.document.add_heading(self.TITLE, level=0)
 
@@ -75,14 +99,16 @@ class ReportDocument:
 
     def _get_variable_info(self):
         """Get a brief introduction, summary statistics, and graphs for each
-        individual variable."""
-        for idx, col in enumerate(self.data.columns, start=1):
-            var = Variable(self.data[col], graph_colour=self.GRAPH_COLOUR)
+        individual variable.
+        """
+        for idx, col in enumerate(tqdm(self.data.columns, ncols=79),
+                                  start=1):
+            var = Variable(self.data[col], graph_color=self.GRAPH_COLOR)
             # Heading
-            self.document.add_heading(f'{idx}. {col.title()}', level=2)
+            self.document.add_heading(f'{idx}. {col}'.title(), level=2)
             # Introduction
             p = self.document.add_paragraph()
-            p.add_run(f'{col.capitalize()}').bold = True
+            p.add_run(f'{col}'.capitalize()).bold = True
             p.add_run(f' is a {var.var_type} variable ')
             p.add_run(f'with {var.num_unique} unique values. ')
             p.add_run(f'{var.missing} of its values are missing.')
@@ -98,7 +124,8 @@ class ReportDocument:
             self.document.add_page_break()
 
     def _get_bivariate_analysis(self):
-        """Get comparisons and scatterplots for pairs of numeric variables."""
+        """Get comparisons and scatterplots for pairs of numeric variables.
+        """
         self.document.add_heading('Bivariate Analysis (Correlation)', level=1)
         self.document.add_paragraph()
         self.document.add_picture(self.variables.joint_correlation_plot,
@@ -108,13 +135,13 @@ class ReportDocument:
         for idx, var_pair in enumerate(self.variables.var_pairs, start=1):
             # Heading
             self.document.add_heading(
-                f'{idx}. {var_pair[0].title()} vs {var_pair[1].title()}',
+                f'{idx}. {var_pair[0]} vs {var_pair[1]}'.title(),
                 level=2)
             # Introductory text
             p = self.document.add_paragraph()
-            p.add_run(f'{var_pair[0].capitalize()}').bold = True
+            p.add_run(f'{var_pair[0]}'.capitalize()).bold = True
             p.add_run(' and ')
-            p.add_run(f'{var_pair[1].capitalize()}').bold = True
+            p.add_run(f'{var_pair[1]}'.capitalize()).bold = True
             p.add_run(f' have {self.variables.corr_type[var_pair]}.')
             # Scatter-plot
             self.document.add_picture(
@@ -128,7 +155,8 @@ class ReportDocument:
                 self.document.add_page_break()
 
     def _create_table(self, data):
-        """Create a table from the given data and add it to the document."""
+        """Create a table from the given data and add it to the document.
+        """
         table = self.document.add_table(rows=len(data), cols=2)
         # Set table style
         table.style = self.document.styles[self.TABLE_STYLE]
@@ -146,5 +174,6 @@ class ReportDocument:
         self.document.add_paragraph()
 
     def _save_file(self):
-        """Save the document as a .docx file."""
+        """Save the document as a .docx file.
+        """
         self.document.save(self.OUTPUT_FILENAME)
